.. _part_bod:

=====================================================
Masses, Inertias & Particles, RigidBodys (Docstrings)
=====================================================

.. automodule:: sympy.physics.mechanics.particle
   :members:

.. automodule:: sympy.physics.mechanics.rigidbody
   :members:

.. autofunction:: sympy.physics.mechanics.functions.inertia

.. autofunction:: sympy.physics.mechanics.functions.inertia_of_point_mass

.. autofunction:: sympy.physics.mechanics.functions.linear_momentum

.. autofunction:: sympy.physics.mechanics.functions.angular_momentum

.. autofunction:: sympy.physics.mechanics.functions.kinetic_energy

.. autofunction:: sympy.physics.mechanics.functions.potential_energy

.. autofunction:: sympy.physics.mechanics.functions.Lagrangian
